AdjustedArithmeticMeanRank
==========================

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: AdjustedArithmeticMeanRank
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~AdjustedArithmeticMeanRank.binarize
      ~AdjustedArithmeticMeanRank.closed_expectation
      ~AdjustedArithmeticMeanRank.closed_variance
      ~AdjustedArithmeticMeanRank.increasing
      ~AdjustedArithmeticMeanRank.key
      ~AdjustedArithmeticMeanRank.name
      ~AdjustedArithmeticMeanRank.needs_candidates
      ~AdjustedArithmeticMeanRank.supported_rank_types
      ~AdjustedArithmeticMeanRank.supports_weights
      ~AdjustedArithmeticMeanRank.synonyms
      ~AdjustedArithmeticMeanRank.value_range

   .. rubric:: Methods Summary

   .. autosummary::

      ~AdjustedArithmeticMeanRank.__call__
      ~AdjustedArithmeticMeanRank.adjust
      ~AdjustedArithmeticMeanRank.expected_value
      ~AdjustedArithmeticMeanRank.get_coefficients
      ~AdjustedArithmeticMeanRank.get_description
      ~AdjustedArithmeticMeanRank.get_link
      ~AdjustedArithmeticMeanRank.get_range
      ~AdjustedArithmeticMeanRank.get_sampled_values
      ~AdjustedArithmeticMeanRank.numeric_expected_value
      ~AdjustedArithmeticMeanRank.numeric_expected_value_with_ci
      ~AdjustedArithmeticMeanRank.numeric_variance
      ~AdjustedArithmeticMeanRank.numeric_variance_with_ci
      ~AdjustedArithmeticMeanRank.std
      ~AdjustedArithmeticMeanRank.variance

   .. rubric:: Attributes Documentation

   .. autoattribute:: binarize
   .. autoattribute:: closed_expectation
   .. autoattribute:: closed_variance
   .. autoattribute:: increasing
   .. autoattribute:: key
   .. autoattribute:: name
   .. autoattribute:: needs_candidates
   .. autoattribute:: supported_rank_types
   .. autoattribute:: supports_weights
   .. autoattribute:: synonyms
   .. autoattribute:: value_range

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: adjust
   .. automethod:: expected_value
   .. automethod:: get_coefficients
   .. automethod:: get_description
   .. automethod:: get_link
   .. automethod:: get_range
   .. automethod:: get_sampled_values
   .. automethod:: numeric_expected_value
   .. automethod:: numeric_expected_value_with_ci
   .. automethod:: numeric_variance
   .. automethod:: numeric_variance_with_ci
   .. automethod:: std
   .. automethod:: variance
